[VOL-3260] Purging all meter state on OLT delete

Change-Id: I6323779d584b341d33cc91231197504b80a91fc4
diff --git a/app/src/main/java/org/opencord/olt/internalapi/AccessDeviceMeterService.java b/app/src/main/java/org/opencord/olt/internalapi/AccessDeviceMeterService.java
index bad2e5b..4b921fb 100644
--- a/app/src/main/java/org/opencord/olt/internalapi/AccessDeviceMeterService.java
+++ b/app/src/main/java/org/opencord/olt/internalapi/AccessDeviceMeterService.java
@@ -70,31 +70,41 @@
     /**
      * Adds the DeviceBandwidthProfile to the pendingMeters.
      *
      * @param deviceBandwidthProfile the device to bandwidth profile mapping
      */
-    void addToPendingMeters(DeviceBandwidthProfile deviceBandwidthProfile);
+    void addToPendingMeters(DeviceId deviceId, BandwidthProfileInformation bwpInfo);
 
     /**
      * Removes the DeviceBandwidthProfile from the pendingMeters.
      *
      * @param deviceBandwidthProfile the device to bandwidth profile mapping
      *
      */
-    void removeFromPendingMeters(DeviceBandwidthProfile deviceBandwidthProfile);
+    void removeFromPendingMeters(DeviceId deviceId, BandwidthProfileInformation bwpInfo);
 
     /**
      * Checks if DeviceBandwidthProfile is pending.
      *
      * @param deviceBandwidthProfile the device to bandwidth profile mapping
      *
      * @return true if pending.
      */
-    boolean isMeterPending(DeviceBandwidthProfile deviceBandwidthProfile);
+    boolean isMeterPending(DeviceId deviceId, BandwidthProfileInformation bwpInfo);
 
     /**
-     * Clears out bandwidth profile to meter mappings for the given device.
+     * Clears out meters for the given device.
      *
      * @param deviceId device ID
      */
     void clearMeters(DeviceId deviceId);
+
+    /**
+     * Clears out local state for the given device.
+     *
+     * @param deviceId device ID
+     */
+    void clearDeviceState(DeviceId deviceId);
 }
@@ -70,31 +70,41 @@
      * Adds the DeviceBandwidthProfile to the pendingMeters.
      *
-     * @param deviceBandwidthProfile the device to bandwidth profile mapping
+     * @param deviceId the device
+     * @param bwpInfo the bandwidth profile info
      */
@@ -70,31 +70,41 @@
      * Removes the DeviceBandwidthProfile from the pendingMeters.
      *
-     * @param deviceBandwidthProfile the device to bandwidth profile mapping
+     * @param deviceId the device
+     * @param bwpInfo the bandwidth profile info
      *
      */
@@ -70,31 +70,41 @@
      * Checks if DeviceBandwidthProfile is pending.
      *
-     * @param deviceBandwidthProfile the device to bandwidth profile mapping
+     * @param deviceId the device
+     * @param bwpInfo the bandwidth profile info
      *
      * @return true if pending.